@@ -249,10 +249,8 @@ gog_axis_base_get_crossed_axis_type (GogAxisBase *axis_base)
 	axis_set = gog_chart_get_axis_set (axis_base->chart);
 
 	crossed_type = GOG_AXIS_UNKNOWN;
-	switch (axis_set) {
+	switch (axis_set & GOG_AXIS_SET_FUNDAMENTAL) {
 		case GOG_AXIS_SET_XY:
-		case GOG_AXIS_SET_XY_pseudo_3d:
-		case GOG_AXIS_SET_XY_COLOR:
 			if (axis_type == GOG_AXIS_X)
 				crossed_type = GOG_AXIS_Y;
 			else
@@ -631,48 +629,68 @@ gog_axis_base_class_init (GObjectClass *gobject_klass)
 	gog_klass->parent_changed 	= gog_axis_base_parent_changed;
 
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_POSITION,
-		g_param_spec_string ("pos_str", "pos_str",
-			"Where to position an axis low, high, or crossing",
-			"low", G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_string ("pos-str", 
+			_("Axis position"),
+			_("Where to position an axis low, high, or crossing"),
+			"low", 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MAJOR_TICK_LABELED,
-		g_param_spec_boolean ("major-tick-labeled", NULL,
-			"Show labels for major ticks",
-			TRUE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("major-tick-labeled", 
+			_("Major labels"),
+			_("Show labels for major ticks"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MAJOR_TICK_IN,
-		g_param_spec_boolean ("major-tick-in", NULL,
-			"Major tick marks inside the axis",
-			FALSE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("major-tick-in", 
+			_("Inside major ticks"),
+			_("Major tick marks inside the chart area"),
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MAJOR_TICK_OUT,
-		g_param_spec_boolean ("major-tick-out", NULL,
-			"Major tick marks outside the axis",
-			TRUE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("major-tick-out", 
+			_("Outside major ticks"),
+			_("Major tick marks outside the chart area"),
+			TRUE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MAJOR_TICK_SIZE_PTS,
-		g_param_spec_int ("major-tick-size-pts", "major-tick-size-pts",
-			"Size of the major tick marks, in points",
-			0, 20, 4, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_int ("major-tick-size-pts", 
+			_("Major tick size"),
+			_("Size of the major tick marks, in points"),
+			0, 20, 4, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MINOR_TICK_IN,
-		g_param_spec_boolean ("minor-tick-in", NULL,
-			"Minor tick marks inside the axis",
-			FALSE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("minor-tick-in", 
+			_("Inside minor ticks"),
+			_("Minor tick marks inside the chart area"),
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MINOR_TICK_OUT,
-		g_param_spec_boolean ("minor-tick-out", NULL,
-			"Minor tick marks outside the axis",
-			FALSE, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_boolean ("minor-tick-out", 
+			_("Outside minor ticks"),
+			_("Minor tick marks outside the axis"),
+			FALSE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_MINOR_TICK_SIZE_PTS,
-		g_param_spec_int ("minor-tick-size-pts", NULL,
-			"Size of the minor tick marks, in points",
-			0, 15, 2, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_int ("minor-tick-size-pts", 
+			_("Minor tick size"),
+			_("Size of the minor tick marks, in points"),
+			0, 15, 2, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_CROSS_AXIS_ID,
-		g_param_spec_uint ("cross_axis_id", NULL,
-			"Which axis to cross",
-			0, G_MAXUINT, 0, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_uint ("cross-axis-id", 
+			_("Cross axis id"),
+			_("Which axis to cross"),
+			0, G_MAXUINT, 0, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 	g_object_class_install_property (gobject_klass, AXIS_BASE_PROP_PADDING_PTS,
-		g_param_spec_int ("padding-pts", NULL,
-			"Distance from axis line to plot area, in points",
-			-G_MAXINT, G_MAXINT, 0, G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
+		g_param_spec_int ("padding-pts", 
+			_("Axis padding"),
+			_("Distance from axis line to plot area, in points"),
+			-G_MAXINT, G_MAXINT, 0, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE | GOG_PARAM_PERSISTENT));
 
 #ifdef GOFFICE_WITH_GTK
 	gog_klass->populate_editor	= gog_axis_base_populate_editor;
@@ -1022,9 +1040,9 @@ axis_line_render (GogAxisBase *axis_base,
 {
 	GogAxisMap *map = NULL;
 	GogAxisTick *ticks;
-	GogViewAllocation label_pos;
 	GogStyle *style = axis_base->base.style;
-	GOGeometryOBR txt_obr, txt_obr_old = {0., 0., 0., 0., 0.};
+	GOGeometryOBR zero_obr;
+	GOGeometryOBR *obrs = NULL;
 	ArtVpath path[3];
 	double line_width;
 	double axis_length, axis_angle, label_padding;
@@ -1034,7 +1052,7 @@ axis_line_render (GogAxisBase *axis_base,
 	double cos_alpha, sin_alpha;
 	double pos, pos_x, pos_y;
 	double padding = gog_axis_base_get_padding (axis_base);
-	unsigned i, tick_nbr;
+	unsigned i, tick_nbr, nobr = 0, *indexmap = NULL;
 	gboolean draw_major, draw_minor;
 	gboolean is_line_visible;
 
@@ -1087,10 +1105,14 @@ axis_line_render (GogAxisBase *axis_base,
 
 	tick_len = axis_base->major.tick_out ? major_tick_len :
 		(axis_base->minor.tick_out ? minor_tick_len : 0.);
-	gog_renderer_get_text_OBR (renderer, "0", TRUE, &txt_obr);
-	label_padding = txt_obr.w;
+	gog_renderer_get_text_OBR (renderer, "0", TRUE, &zero_obr);
+	label_padding = zero_obr.w;
 
 	tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
+	if (draw_labels) {
+		obrs = g_new0 (GOGeometryOBR, tick_nbr);
+		indexmap = g_new0 (unsigned int, tick_nbr);
+	}
 
 	for (i = 0; i < tick_nbr; i++) {
 		if (gog_axis_map (map, ticks[i].position) < start_at)
@@ -1134,22 +1156,51 @@ axis_line_render (GogAxisBase *axis_base,
 		}
 
 		if (ticks[i].label != NULL && draw_labels) {
+			GOGeometryOBR *obr = obrs + nobr;
 			pos = gog_axis_map_to_view (map, ticks[i].position);
-			gog_renderer_get_text_OBR (renderer, ticks[i].label, TRUE, &txt_obr);
-			txt_obr.w += label_padding;
-			go_geometry_calc_label_position (&txt_obr, axis_angle, tick_len, side);
-			txt_obr.x += x + pos * cos (axis_angle);
-			txt_obr.y += y + pos * sin (axis_angle);
-			if (!go_geometry_test_OBR_overlap (&txt_obr, &txt_obr_old)) {
-				label_pos.x = txt_obr.x;
-				label_pos.y = txt_obr.y;
-				gog_renderer_draw_text (renderer, ticks[i].label,
-							&label_pos, GTK_ANCHOR_CENTER, TRUE);
-				txt_obr_old = txt_obr;
-			}
+			gog_renderer_get_text_OBR (renderer, ticks[i].label, TRUE, obr);
+			obr->w += label_padding;
+			go_geometry_calc_label_position (obr, axis_angle, tick_len, side);
+			obr->x += x + pos * cos (axis_angle);
+			obr->y += y + pos * sin (axis_angle);
+
+			indexmap[nobr] = i;
+			nobr++;
 		}
 	}
 
+	/*
+	 * This is far from perfect, but at least things are regular.
+	 * The axis really needs to be queried to figure this out,
+	 * especially if dates are involved.
+	 */
+	if (nobr > 0) {
+		int skip = 1;
+
+		for (i = skip; i < nobr; i += skip) {
+			gboolean overlap =
+				go_geometry_test_OBR_overlap (obrs + i,
+							      obrs + i + skip);
+			if (overlap) {
+				skip++;
+				i = 0;
+				continue;
+			}
+		}
+
+		for (i = 0; i < nobr; i += skip) {
+			unsigned j = indexmap[i];
+			GogViewAllocation label_pos;
+			label_pos.x = obrs[i].x;
+			label_pos.y = obrs[i].y;
+			gog_renderer_draw_text (renderer, ticks[j].label,
+						&label_pos, GTK_ANCHOR_CENTER,
+						TRUE);
+		}
+	}
+	g_free (obrs);
+	g_free (indexmap);
+
 	gog_axis_map_free (map);
 }
 
@@ -1675,22 +1726,19 @@ gog_axis_base_view_padding_request (GogView *view, GogViewAllocation const *bbox
 	GogAxisBase *axis_base = GOG_AXIS_BASE (view->model);
 	GogStyle *style = axis_base->base.style;
 
+	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
+		return;
 	axis_set = gog_chart_get_axis_set (axis_base->chart);
 
 	gog_renderer_push_style (view->renderer, style);
 
-	switch (axis_set) {
+	switch (axis_set & GOG_AXIS_SET_FUNDAMENTAL) {
 		case GOG_AXIS_SET_X:
 			x_process (GOG_AXIS_BASE_PADDING_REQUEST, view, padding, bbox, 0., 0.);
 			break;
 		case GOG_AXIS_SET_XY:
 			xy_process (GOG_AXIS_BASE_PADDING_REQUEST, view, padding, bbox, 0., 0.);
 			break;
-		case GOG_AXIS_SET_XY_pseudo_3d:
-		case GOG_AXIS_SET_XY_COLOR:
-			if (gog_axis_get_atype (axis_base->axis) < GOG_AXIS_VIRTUAL)
-				xy_process (GOG_AXIS_BASE_PADDING_REQUEST, view, padding, bbox, 0., 0.);
-			break;
 		case GOG_AXIS_SET_RADAR:
 			radar_process (GOG_AXIS_BASE_PADDING_REQUEST, view, padding, bbox, 0., 0.);
 			break;
@@ -1713,6 +1761,9 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 	GogStyle *style = axis_base->base.style;
 	GogViewAllocation const *plot_area;
 
+	if (gog_axis_get_atype (axis_base->axis) >= GOG_AXIS_VIRTUAL)
+		return;
+
 	axis_set = gog_chart_get_axis_set (axis_base->chart);
 	/* FIXME: not nice */
 	if (IS_GOG_AXIS (view->model))
@@ -1722,18 +1773,13 @@ gog_axis_base_view_render (GogView *view, GogViewAllocation const *bbox)
 
 	gog_renderer_push_style (view->renderer, style);
 
-	switch (axis_set) {
+	switch (axis_set & GOG_AXIS_SET_FUNDAMENTAL) {
 		case GOG_AXIS_SET_X:
 			x_process (GOG_AXIS_BASE_RENDER, view, NULL, plot_area, 0., 0.);
 			break;
 		case GOG_AXIS_SET_XY:
 			xy_process (GOG_AXIS_BASE_RENDER, view, NULL, plot_area, 0., 0.);
 			break;
-		case GOG_AXIS_SET_XY_pseudo_3d:
-		case GOG_AXIS_SET_XY_COLOR:
-			if (gog_axis_get_atype (axis_base->axis) < GOG_AXIS_VIRTUAL)
-				xy_process (GOG_AXIS_BASE_RENDER, view, NULL, plot_area, 0., 0.);
-			break;
 		case GOG_AXIS_SET_RADAR:
 			radar_process (GOG_AXIS_BASE_RENDER, view, NULL, plot_area, 0., 0.);
 			break;
