@@ -36,6 +36,8 @@
 #include <gsf/gsf.h>
 #include <gsf/gsf-impl-utils.h>
 
+#include <glib/gi18n-lib.h>
+
 enum {
 	RENDERER_PROP_0,
 	RENDERER_PROP_MODEL,
@@ -162,6 +164,19 @@ gog_renderer_invalidate_size_requests (GogRenderer *rend)
 		gog_renderer_request_update (rend);
 }
 
+static double
+line_size (GogRenderer const *rend, double width, gboolean sharp)
+{
+	GogRendererClass *klass = GOG_RENDERER_GET_CLASS (rend);
+
+	if (klass->line_size)
+		return (klass->line_size) (rend, width, sharp);
+
+	if (go_sub_epsilon (width) <= 0.)
+		width = GOG_RENDERER_HAIRLINE_WIDTH_PTS;
+	return width * rend->scale;
+}
+
 static void
 update_dash (GogRenderer *rend)
 {
@@ -175,9 +190,9 @@ update_dash (GogRenderer *rend)
 	if (rend->cur_style == NULL)
 		return;
 
-	size = gog_renderer_line_size (rend, rend->cur_style->line.width);
+	size = line_size (rend, rend->cur_style->line.width, FALSE);
 	rend->line_dash = go_line_get_vpath_dash (rend->cur_style->line.dash_type, size);
-	size = gog_renderer_line_size (rend, rend->cur_style->outline.width);
+	size = line_size (rend, rend->cur_style->outline.width, FALSE);
 	rend->outline_dash = go_line_get_vpath_dash (rend->cur_style->outline.dash_type, size);
 }
 
@@ -474,12 +489,7 @@ gog_renderer_draw_sharp_path (GogRenderer *rend, ArtVpath *path)
 	g_return_if_fail (klass != NULL);
 	g_return_if_fail (rend->cur_style != NULL);
 
-	if (klass->sharp_path) {
-		(klass->sharp_path) (rend, path, 
-			gog_renderer_line_size (rend, rend->cur_style->line.width));
-	}
-
-	(klass->draw_path) (rend, path);
+	(klass->draw_path) (rend, path, TRUE);
 }
 
 /**
@@ -497,7 +507,7 @@ gog_renderer_draw_path (GogRenderer *rend, ArtVpath const *path)
 	g_return_if_fail (klass != NULL);
 	g_return_if_fail (rend->cur_style != NULL);
 
-	(klass->draw_path) (rend, path);
+	(klass->draw_path) (rend, path, FALSE);
 }
 
 /**
@@ -518,12 +528,7 @@ gog_renderer_draw_sharp_polygon (GogRenderer *rend, ArtVpath *path, gboolean nar
 	g_return_if_fail (klass != NULL);
 	g_return_if_fail (rend->cur_style != NULL);
 
-	if (klass->sharp_path) {
-		(klass->sharp_path) (rend, path,
-			gog_renderer_line_size (rend, rend->cur_style->outline.width));
-	}
-
-	(klass->draw_polygon) (rend, path, narrow);
+	(klass->draw_polygon) (rend, path, TRUE, narrow);
 }
 
 /**
@@ -543,7 +548,7 @@ gog_renderer_draw_polygon (GogRenderer *rend, ArtVpath const *path, gboolean nar
 	g_return_if_fail (klass != NULL);
 	g_return_if_fail (rend->cur_style != NULL);
 
-	(klass->draw_polygon) (rend, path, narrow);
+	(klass->draw_polygon) (rend, path, FALSE, narrow);
 }
 
 
@@ -688,22 +693,27 @@ gog_renderer_class_init (GogRendererClass *renderer_klass)
 	gobject_klass->set_property = gog_renderer_set_property;
 	gobject_klass->get_property = gog_renderer_get_property;
 
-	renderer_klass->sharp_path = NULL;
 	renderer_klass->line_size = NULL;
 	renderer_klass->export_image = NULL;
 
 	g_object_class_install_property (gobject_klass, RENDERER_PROP_MODEL,
-		g_param_spec_object ("model", "model",
-			"the GogGraph this renderer displays",
-			GOG_GRAPH_TYPE, G_PARAM_READWRITE));
+		g_param_spec_object ("model", 
+			_("Model"),
+			_("The GogGraph this renderer displays"),
+			GOG_GRAPH_TYPE, 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 	g_object_class_install_property (gobject_klass, RENDERER_PROP_VIEW,
-		g_param_spec_object ("view", "view",
-			"the GogView this renderer is displaying",
-			GOG_VIEW_TYPE, G_PARAM_READABLE));
+		g_param_spec_object ("view", 
+			_("View"),
+			_("the GogView this renderer is displaying"),
+			GOG_VIEW_TYPE, 
+			GSF_PARAM_STATIC | G_PARAM_READABLE));
 	g_object_class_install_property (gobject_klass, RENDERER_PROP_ZOOM,
-		g_param_spec_double ("zoom", "zoom Height Pts",
-			"global scale factor",
-			1., G_MAXDOUBLE, 1., G_PARAM_READWRITE));
+		g_param_spec_double ("zoom", 
+			_("Zoom Height Pts"),
+			_("Global scale factor"),
+			1., G_MAXDOUBLE, 1., 
+			GSF_PARAM_STATIC | G_PARAM_READWRITE));
 
 	renderer_signals [RENDERER_SIGNAL_REQUEST_UPDATE] = g_signal_new ("request-update",
 		G_TYPE_FROM_CLASS (renderer_klass),
@@ -790,14 +800,7 @@ gog_renderer_draw_rectangle (GogRenderer *rend, GogViewAllocation const *rect)
 double
 gog_renderer_line_size (GogRenderer const *rend, double width)
 {
-	GogRendererClass *klass = GOG_RENDERER_GET_CLASS (rend);
-
-	if (klass->line_size)
-		return (klass->line_size) (rend, width);
-	
-	if (go_sub_epsilon (width) <= 0.)
-		width = GOG_RENDERER_HAIR_LINE_WIDTH;
-	return width * rend->scale;
+	return line_size (rend, width, TRUE);
 }
 
 double
@@ -818,6 +821,25 @@ gog_renderer_pt2r (GogRenderer const *rend, double d)
 	return d * rend->scale;
 }
 
+/**
+ * gog_renderer_get_hairline_width_pts:
+ * @rend: a #GogRenderer
+ *
+ * returns the hairline width in pts.
+ **/
+double
+gog_renderer_get_hairline_width_pts (GogRenderer const *rend)
+{
+	GogRendererClass *klass = GOG_RENDERER_GET_CLASS (rend);
+
+	g_return_val_if_fail (klass != NULL, GOG_RENDERER_HAIRLINE_WIDTH_PTS);
+
+	if (klass->hairline_pts)
+		return (klass->hairline_pts) (rend);
+
+	return GOG_RENDERER_HAIRLINE_WIDTH_PTS;
+}
+
 /**
  * gog_renderer_draw_grip:
  * @renderer : #GogRenderer
