@@ -320,6 +320,14 @@ go_string_append_gstring (GString *target, const GString *source)
 	g_string_append_len (target, source->str, source->len);
 }
 
+void
+go_string_append_c_n (GString *target, char c, gsize n)
+{
+	gsize len = target->len;
+	g_string_set_size (target, len + n);
+	memset (target->str + len, c, n);
+}
+
 /* ------------------------------------------------------------------------- */
 
 /**
@@ -637,12 +645,11 @@ go_mem_chunk_foreach_leak (GOMemChunk *chunk, GFunc cb, gpointer user)
 int
 go_str_compare (void const *x, void const *y)
 {
-	if (x == NULL || y == NULL) {
-		if (x == y)
-			return 0;
-		else
-			return x ? -1 : 1;
-	}
+	if (x == y)
+		return 0;
+
+	if (x == NULL || y == NULL)
+		return x ? -1 : 1;
 
 	return strcmp (x, y);
 }
